#!/usr/bin/env node

/*
 * @Author: Yuki
 * @Date: 2021-04-12 10:54:42
 * @LastEditTime: 2021-05-10 11:49:12
 * @LastEditors: Please set LastEditors
 * @Description: 调整输入方式
 * @FilePath: \npm-tools\yuki-next-server-express\src\index.js
 */
"use strict";

var next = require('next');

var _require = require('url'),
    parse = _require.parse;

var dev = process.env.NODE_ENV !== 'production';
var app = next({
  dev: dev
});
var handle = app.getRequestHandler();

var express = require('express');

var cookieParser = require('cookie-parser');

var _require2 = require('http-proxy-middleware'),
    proxyMiddleware = _require2.createProxyMiddleware;

var path = require('path');

var fs = require('fs');

var port = 3000;
var devProxy = null;

var serverAllFunc = function serverAllFunc(req, res) {
  var parsedUrl = parse(req.url, true);
  handle(req, res, parsedUrl);
};

if (fs.existsSync(path.resolve(process.cwd(), './server/server.config.js'))) {
  var _require3 = require(path.resolve(process.cwd(), './server/server.config.js')),
      newPort = _require3.port,
      newDevProxy = _require3.devProxy,
      newHandlers = _require3.handlers;

  if (newPort) port = newPort;
  if (newDevProxy) devProxy = newDevProxy;
  if (newHandlers) serverAllFunc = newHandlers;
}

var serverPort = parseInt(process.env.PORT, 10) || port;
var io = null;
app.prepare().then(function () {
  var server = express();

  var httpServer = require('http').createServer(server);

  if (devProxy) Object.keys(devProxy).forEach(function (context) {
    server.use(proxyMiddleware(context, devProxy[context]));
  });
  server.use(express.json());
  server.use(cookieParser());
  server.use(express.urlencoded({
    extended: true
  })); //调用中间件

  var routeNames = fs.readdirSync(path.resolve(process.cwd(), './server/routes')).map(function (routeName) {
    return routeName.split('.')[0];
  });
  routeNames.forEach(function (routeName) {
    var filenames = fs.readdirSync(path.resolve(process.cwd(), "./server/routes/".concat(routeName))).map(function (filename) {
      return filename.split('.')[0];
    });
    filenames.forEach(function (filename) {
      server.use("/".concat(routeName, "/").concat(filename), require(path.resolve(process.cwd(), "./server/routes/".concat(routeName, "/").concat(filename))));
    });
  });
  server.all('*', function (req, res) {
    return serverAllFunc(req, res, app, parse);
  }); // socket

  if (fs.existsSync(path.resolve(process.cwd(), './server/socket/index.js'))) {
    io = require('socket.io')(httpServer, {
      cors: true
    });

    var socket = require(path.resolve(process.cwd(), './server/socket'));

    socket(io);
  }

  httpServer.listen(serverPort, function (err) {
    if (err) throw err;
    console.log("> Ready on http://localhost:".concat(serverPort));
  });
})["catch"](function (err) {
  console.log('An error occurred, unable to start the server');
  console.log(err);
});
module.exports = {
  io: io
};
//# sourceMappingURL=index.js.map